﻿namespace Sample.Controllers
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Web.Mvc;
    using Infragistics.Web.Mvc;
    using Sample.Models;

    public class HomeController : Controller
    {
        private List<Vacation> vacations;

        public ActionResult Index()
        {
            var vacations = GenerateVacation(10).AsQueryable();

            return View(vacations);
        }

        private IEnumerable<Vacation> GenerateVacation(int count)
        {
            if (this.vacations != null)
            {
                return this.vacations;
            }

            this.vacations = new List<Vacation>();

            for (int i = 1; i <= count; i++)
            {
                vacations.Add(new Vacation(i, "Some nice place " + i, DateTime.Now.AddDays(i), DateTime.Now.AddDays(i + 7)));
            }

            return vacations;
        }

        public ActionResult SaveData()
        {
            GridModel gridModel = new GridModel();
            var transactions = gridModel.LoadTransactions<Vacation>(HttpContext.Request.Form["ig_transactions"]);

            foreach (Transaction<Vacation> transaction in transactions)
            {
                switch (transaction.type)
                {
                    case "newrow":
                        AddNewVacation(transaction);
                        break;
                    case "deleterow":
                        DeleteVacation(transaction);
                        break;
                    case "row":
                        UpdateVacation(transaction);
                        break;
                    default:
                        break;
                }
            }

            JsonResult result = new JsonResult();
            Dictionary<string, bool> response = new Dictionary<string, bool>();
            response.Add("Success", true);
            result.Data = response;
            return result;
        }

        private void AddNewVacation(Transaction<Vacation> transaction)
        {
            this.vacations.Add(transaction.row);
        }

        private void DeleteVacation(Transaction<Vacation> transaction)
        {
            this.vacations.RemoveAll(v => v.Id == transaction.row.Id);
        }

        private void UpdateVacation(Transaction<Vacation> transaction)
        {
            var vacation = vacations.Where(v => v.Id == transaction.row.Id).FirstOrDefault();

            if (vacation == null)
            {
                return;
            }

            vacation.Location = transaction.row.Location;
            vacation.From = transaction.row.From;
            vacation.To = transaction.row.To;
        }
    }
}